@@ -1,6 +1,6 @@
 #' Partial AUC Estimation and Inference
 #'
-#' Estimate and infer the area of region under ROC curve with pre-specific FPR constraint (FPR-pAUC). See \href{http://www3.stat.sinica.edu.tw/ss_newpaper/SS-13-367_na.pdf}{Yang et al., 2016} for details.
+#' Estimate and infer the area of region under ROC curve with pre-specific FPR constraint (FPR-pAUC). See \href{http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html}{Yang et al., 2017} for details.
 #' 
 #' @param response a factor, numeric or character vector of responses; 
 #'    typically encoded with 0 (negative) and 1 (positive). 
@@ -9,15 +9,14 @@
 #'    
 #' @param predictor a numeric vector of the same length than response, containing the predicted value of each observation. An ordered factor is coerced to a numeric.
 #' @param threshold numeric; false positive rate (FPR) constraint.
-#' @param method methods to estimate FPR-pAUC. \code{MW}: Mann-Whitney statistic. \code{expect}: method in (2.2) \href{http://www.ncbi.nlm.nih.gov/pubmed/20729218}{Wang and Chang, 2011}. \code{jackknife}: jackknife method in \href{http://www3.stat.sinica.edu.tw/ss_newpaper/SS-13-367_na.pdf}{Yang et al., 2016}.
+#' @param method methods to estimate FPR-pAUC. \code{MW}: Mann-Whitney statistic. \code{expect}: method in (2.2) \href{http://www.ncbi.nlm.nih.gov/pubmed/20729218}{Wang and Chang, 2011}. \code{jackknife}: jackknife method in \href{http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html}{Yang et al., 2017}.
 #' @param ci logic; compute the confidence interval of estimation?
 #' @param cp numeric; coverage probability of confidence interval. 
-#' @param plot  logic; plot the ROC curve? 
 #' @param smooth if \code{TRUE}, the ROC curve is passed to \code{\link[pROC]{smooth}} to be smoothed.
 #' 
-#' @details This function estimates and infers FPR partial AUC given response, predictor and pre-specific FPR constraint. The plot of corresponding ROC curve with pre-specific FPR is generated.
-#'          \code{MW}: Mann-Whitney statistic. \code{expect}: method in (2.2) \href{http://www.ncbi.nlm.nih.gov/pubmed/20729218}{Wang and Chang, 2011}. \code{jackknife}: jackknife method in \href{http://www3.stat.sinica.edu.tw/ss_newpaper/SS-13-367_na.pdf}{Yang et al., 2016}.
-#' @return Estimation and Inference of FPR partial AUC. 
+#' @details This function estimates and infers FPR partial AUC given response, predictor and pre-specific FPR constraint.
+#'          \code{MW}: Mann-Whitney statistic. \code{expect}: method in (2.2) \href{http://www.ncbi.nlm.nih.gov/pubmed/20729218}{Wang and Chang, 2011}. \code{jackknife}: jackknife method in \href{http://www3.stat.sinica.edu.tw/statistica/j27n1/j27n117/j27n117.html}{Yang et al., 2017}.
+#' @return Estimate and Inference of FPR partial AUC. 
 #'
 #' @author Hanfang Yang, Kun Lu, Xiang Lyu, Feifang Hu, Yichuan Zhao.
 #' @seealso \code{\link[pROC]{roc}}, \code{\link[tpAUC]{tproc.est}}, \code{\link[tpAUC]{proc.est}}, \code{\link[tpAUC]{proc.ci}}
@@ -26,7 +25,7 @@
 #' 
 #' library('pROC')
 #' data(aSAH)
-#' proc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95, plot=TRUE)
+#' proc(aSAH$outcome, aSAH$s100b,threshold=0.9, method='expect',ci=TRUE, cp=0.95)
 #' 
 #' @export 
 #'
@@ -35,8 +34,8 @@
 #' @importFrom graphics lines abline      
 #'          
 #'        
-proc=function(response,predictor,threshold=0.9, method='MW',ci=TRUE, cp=0.95, plot=TRUE,smooth=FALSE) {
-  pauc=proc.est(response,predictor,threshold=threshold, method=method, plot=plot,smooth=smooth)
+proc=function(response,predictor,threshold=0.9, method='MW',ci=TRUE, cp=0.95, smooth=FALSE) {
+  pauc=proc.est(response,predictor,threshold=threshold, method=method,smooth=smooth)
   l=list(pauc=pauc)
   if (ci==TRUE){
     c=proc.ci(response,predictor, cp=cp ,threshold=threshold,method=method )
